==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/NextMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { NextMonthExpressionDescription } from "./NextMonthExpressionDescription";
/**
 * @hidden
 */
var NextMonthExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NextMonthExpressionDescriptionMetadata, _super);
    function NextMonthExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NextMonthExpressionDescriptionMetadata.b = function (a) {
        if (NextMonthExpressionDescriptionMetadata.a == null) {
            NextMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NextMonthExpressionDescriptionMetadata.c(NextMonthExpressionDescriptionMetadata.a);
        }
        if (a.j(NextMonthExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(NextMonthExpressionDescriptionMetadata.a);
    };
    NextMonthExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    NextMonthExpressionDescriptionMetadata.d = function (a) {
        NextMonthExpressionDescriptionMetadata.b(a);
        a.aa("NextMonthExpression", function () { return new NextMonthExpressionDescription(); });
        a.z("NextMonthExpression", NextMonthExpressionDescriptionMetadata.a);
    };
    NextMonthExpressionDescriptionMetadata.$t = markType(NextMonthExpressionDescriptionMetadata, 'NextMonthExpressionDescriptionMetadata');
    NextMonthExpressionDescriptionMetadata.a = null;
    return NextMonthExpressionDescriptionMetadata;
}(Base));
export { NextMonthExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/NextMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { NextMonthExpressionDescription } from "./NextMonthExpressionDescription";
/**
 * @hidden
 */
var NextMonthExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NextMonthExpressionDescriptionMetadata, _super);
    function NextMonthExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NextMonthExpressionDescriptionMetadata.b = function (a) {
        if (NextMonthExpressionDescriptionMetadata.a == null) {
            NextMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NextMonthExpressionDescriptionMetadata.c(NextMonthExpressionDescriptionMetadata.a);
        }
        if (a.k(NextMonthExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(NextMonthExpressionDescriptionMetadata.a);
    };
    NextMonthExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    NextMonthExpressionDescriptionMetadata.d = function (a) {
        NextMonthExpressionDescriptionMetadata.b(a);
        a.ac("NextMonthExpression", function () { return new NextMonthExpressionDescription(); });
        a.ab("NextMonthExpression", NextMonthExpressionDescriptionMetadata.a);
    };
    NextMonthExpressionDescriptionMetadata.$t = markType(NextMonthExpressionDescriptionMetadata, 'NextMonthExpressionDescriptionMetadata');
    NextMonthExpressionDescriptionMetadata.a = null;
    return NextMonthExpressionDescriptionMetadata;
}(Base));
export { NextMonthExpressionDescriptionMetadata };
